package com.admarvel.androidautorefreshdemo;

import java.util.HashMap;
import java.util.Map;
import java.util.Timer;
import java.util.TimerTask;

import com.admarvel.android.ads.AdMarvelUtils.ErrorReason;
import com.admarvel.android.ads.AdMarvelUtils.SDKAdNetwork;
import com.admarvel.android.ads.AdMarvelView;

import com.admarvel.android.ads.AdMarvelView.AdMarvelViewListener;
import com.medialets.advertising.AdManager;



import android.app.Activity;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;

public class AdMarvelAutoRefreshDemo extends Activity implements
		AdMarvelViewListener
{
	
	private static boolean medialetsInitialized = false;
	
	@Override
	public void onStart() {
		super.onStart();
		try {
			// Initialized SDKs that need to; pass in publisher ids
			Map<SDKAdNetwork, String> publisherIds = new HashMap<SDKAdNetwork, String>();
			
			AdMarvelView.initialize(this, publisherIds);

		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		// your code
	}
	
	private BroadcastReceiver mServiceReceiver = new BroadcastReceiver() {
        @Override
        public void onReceive(final Context pContext, final Intent pIntent) {
            if (AdManager.ACTION_SYNC_COMPLETE.equals(pIntent.getAction())) {
            	Log.e("admarvel","Medialets: Sync Completed ");
            	medialetsInitialized = true;
            }
        }
    };

	@Override
	protected void onPause() {
		// TODO Auto-generated method stub
		super.onPause();

		requestIntervalTimer.cancel();
		
		try {
			// Initialized SDKs that need to; pass in publisher ids
			Map<SDKAdNetwork, String> publisherIds = new HashMap<SDKAdNetwork, String>();
			
			AdMarvelView adMarvelView = (AdMarvelView) findViewById(R.id.ad);

			AdMarvelView.pause(this, publisherIds, adMarvelView);
			unregisterReceiver(mServiceReceiver);

		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	@Override
	protected void onResume() {
		// TODO Auto-generated method stub
		super.onResume();
		
		scheduleTimeThread();

		try {
			// Initialized SDKs that need to; pass in publisher ids
			Map<SDKAdNetwork, String> publisherIds = new HashMap<SDKAdNetwork, String>();
			
			AdMarvelView adMarvelView = (AdMarvelView) findViewById(R.id.ad);

			AdMarvelView.resume(this, publisherIds, adMarvelView);
			
			IntentFilter intentFilter = new IntentFilter();
	        intentFilter.addAction(AdManager.ACTION_SYNC_STARTED);
	        intentFilter.addAction(AdManager.ACTION_SYNC_COMPLETE);
	        
	        registerReceiver(mServiceReceiver, intentFilter);

		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	@Override
	public void onStop() {
		super.onStop();

		try {
			Map<SDKAdNetwork, String> publisherIds = new HashMap<SDKAdNetwork, String>();
			
			AdMarvelView.uninitialize(this, publisherIds);

		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// your code
	}
	
	@Override
	protected void onDestroy() {
		// TODO Auto-generated method stub
		super.onDestroy();
		AdMarvelView adMarvelView = (AdMarvelView) findViewById(R.id.ad);
		if (adMarvelView != null) {
			adMarvelView.destroy();
		}
	}


	private Timer requestIntervalTimer;

	private void scheduleTimeThread()
	{
		int requestInterval = 20000;
		requestIntervalTimer = new Timer();
		requestIntervalTimer.schedule(new TimerTask()
		{
			public void run()
			{
				runOnUiThread(TimerRunnable);
				
			}
		}, 0, requestInterval);
	}
	
	private Runnable TimerRunnable = new Runnable() {
		public void run() {

			try
			{
				Map<String, Object> targetParams = new HashMap<String, Object>();
				
				//Always pass this params to request Medialet Ad
				targetParams.put("medialetsInitialized",medialetsInitialized ? "true" : "false");
				
				AdMarvelView adMarvelView = (AdMarvelView) findViewById(R.id.ad);
				
				adMarvelView.requestNewAd(targetParams, "1dd21b33bd603c95", "1429");
			}
			catch (Exception e)
			{
				Log.e("admarvel", Log.getStackTraceString(e));
			}

		}
	};

	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState)
	{
		try
		{
			super.onCreate(savedInstanceState);

			setContentView(R.layout.main);
						
			AdMarvelView adMarvelView = (AdMarvelView) findViewById(R.id.ad);
			
			adMarvelView.setEnableClickRedirect(true);
			adMarvelView.setDisableAnimation(false);
			adMarvelView.setEnableAutoScaling(true);
			adMarvelView.setListener(this);
			
			Button showButton = (Button) findViewById(R.id.ShowButton);
			showButton.setOnClickListener(new OnClickListener() {
				public void onClick(View v) {
					AdMarvelView adMarvelView = (AdMarvelView) findViewById(R.id.ad);
					adMarvelView.setVisibility(View.VISIBLE);
				}
			});
			
			Button hideButton = (Button) findViewById(R.id.HideButton);
			hideButton.setOnClickListener(new OnClickListener() {
				public void onClick(View v) {
					AdMarvelView adMarvelView = (AdMarvelView) findViewById(R.id.ad);
					adMarvelView.setVisibility(View.GONE);
				}
			});

		}
		catch (Exception e)
		{
			Log.e("admarvel", Log.getStackTraceString(e));
		}
	}

	public void onClickAd(AdMarvelView adMarvelView, String clickUrl) {
		if (clickUrl != null) {
			Log.e("admarvel", "ClickUrl: " + clickUrl);
		}
		
	}

	
	public void onFailedToReceiveAd(AdMarvelView adMarvelView, int errorCode,
			ErrorReason errorReason) {
		Log.e("admarvel", "onFailedToReceiveAd; errorCode: " + errorCode + " errorReason: " + errorReason.toString());

	}

	public void onReceiveAd(AdMarvelView adMarvelView) {
		Log.e("admarvel", "onReceiveAd");		
	}

	public void onRequestAd(AdMarvelView adMarvelView) {
		Log.e("admarvel", "onRequestAd");
		
	}
	
	public void onExpand() {
		Log.e("admarvel", "onExpand");
		
	}

	public void onClose() {
		Log.e("admarvel", "onClose");
		
	}
		
}
